@@ -6,7 +6,11 @@
 import sys
 import os
 from . import wifi_qrcode_created
+# import wifi_qrcode_created
 from . import wifi_qrcode_gener
+# import wifi_qrcode_gener
+from . import wifi_qrcode_scanner
+# import wifi_qrcode_scanner
 def wifiqr():
     xdgop = "xdg-open '/tmp/key.png'"
     print('1) Create Wifi QR Code')
@@ -29,6 +33,6 @@ def wifiqr():
         os.system(xdgop)
         print("The qr code has been generated.")
     elif chmanu == "3":
-        print("qrscanner Under processing...")
+        wifi_qrcode_scanner
     else:
         print('\n\n!!!!!!!!!!!!!!!Something Wrong!!!!!!!!!!!!!!!\n\n')
\ No newline at end of file
